psychopy_ext.exp.GroupStim
==========================

.. currentmodule:: psychopy_ext.exp

.. autoclass:: GroupStim

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
   
      ~GroupStim.__init__
   
   

   
   
   